[−][src]Struct iota_utils::StopWatch
Provides a stopwatch for measuring how long things take... this might seem like a weird addition to the library, but it was in Jota...so I put it here. If no one uses this, I'll probably remove it later.
Methods
impl StopWatch[src]
pub fn new() -> StopWatch[src]
Creates a new stopwatch
pub fn restart(&mut self)[src]
Restarts the stopwatch
pub fn stop(self) -> Duration[src]
Stops the stopwatch and returns the duration
pub fn pause(&mut self)[src]
Pauses the stopwatch
pub fn resume(&mut self)[src]
Resumes the stopwatch
pub fn elapsed_time(&self) -> Duration[src]
Returns the elapsed time so far
pub fn is_running(&self) -> bool[src]
Checks whether the stopwatch is running